[SCM] Multi-format 1D/2D barcode image processing library branch, upstream, updated. 24d4480bc48cf9eabf7b2bd2f528248b0e458809

srowen srowen at 59b500cc-1b3d-0410-9834-0bbf25fbcc57
Wed Aug 4 01:31:07 UTC 2010


The following commit has been merged in the upstream branch:
commit 9aeefe94e7fe5485a83f16f4aa1997c610e5804f
Author: srowen <srowen at 59b500cc-1b3d-0410-9834-0bbf25fbcc57>
Date:   Mon Apr 19 09:23:43 2010 +0000

    Use RSS14 on the command line; scan more lines since RSS14 stacked kind of needs this; fix VerifyError when RSS14 is enabled on Android
    
    git-svn-id: http://zxing.googlecode.com/svn/trunk@1311 59b500cc-1b3d-0410-9834-0bbf25fbcc57

diff --git a/android/build.xml b/android/build.xml
index d2f7b74..d619e40 100644
--- a/android/build.xml
+++ b/android/build.xml
@@ -205,7 +205,8 @@ limitations under the License.
       <!-- This works around some strange Android/ProGuard problem verifying MaskUtil -->
       <arg value="-keep class com.google.zxing.qrcode.encoder.MaskUtil { public * ; }"/>
       <arg value="-target 5"/>
-      <arg value="-optimizationpasses 4"/>
+      <!-- Keeping this low also avoids some weird Android/ProGuard issue I couldn't resolve otherwise --> 
+      <arg value="-optimizationpasses 2"/>
       <arg value="-dontshrink"/>
       <arg value="-dontobfuscate"/>
       <arg value="-dontskipnonpubliclibraryclasses"/>
diff --git a/javase/src/com/google/zxing/client/j2se/CommandLineRunner.java b/javase/src/com/google/zxing/client/j2se/CommandLineRunner.java
index f1b30fa..8ac1de4 100644
--- a/javase/src/com/google/zxing/client/j2se/CommandLineRunner.java
+++ b/javase/src/com/google/zxing/client/j2se/CommandLineRunner.java
@@ -113,6 +113,7 @@ public final class CommandLineRunner {
     vector.addElement(BarcodeFormat.UPC_E);
     vector.addElement(BarcodeFormat.EAN_13);
     vector.addElement(BarcodeFormat.EAN_8);
+    vector.addElement(BarcodeFormat.RSS14);    
     if (!productsOnly) {
       vector.addElement(BarcodeFormat.CODE_39);
       vector.addElement(BarcodeFormat.CODE_128);

diff --git a/core/src/com/google/zxing/oned/OneDReader.java b/core/src/com/google/zxing/oned/OneDReader.java
index 0717c5d..bad1f6a 100644
--- a/core/src/com/google/zxing/oned/OneDReader.java
+++ b/core/src/com/google/zxing/oned/OneDReader.java
@@ -103,12 +103,12 @@ public abstract class OneDReader implements Reader {
 
     int middle = height >> 1;
     boolean tryHarder = hints != null && hints.containsKey(DecodeHintType.TRY_HARDER);
-    int rowStep = Math.max(1, height >> (tryHarder ? 8 : 4));
+    int rowStep = Math.max(1, height >> (tryHarder ? 8 : 5));
     int maxLines;
     if (tryHarder) {
       maxLines = height; // Look at the whole image, not just the center
     } else {
-      maxLines = 9; // Nine rows spaced 1/16 apart is roughly the middle half of the image
+      maxLines = 15; // 15 rows spaced 1/32 apart is roughly the middle half of the image
     }
 
     for (int x = 0; x < maxLines; x++) {
-- 
Multi-format 1D/2D barcode image processing library



More information about the Pkg-google-commits mailing list